@@ -25,11 +25,14 @@ LogHighlighter::LogHighlighter(QTextDocument *parent)
 
 void LogHighlighter::highlightBlock(const QString &text)
 {
-if (text.indexOf("!",0)!=-1) 
+QRegExp rxLatexError("! (.*)");
+QRegExp rxBadBox("(Over|Under)(full \\\\[hv]box .*)");
+QRegExp rxWarning("(((! )?(La|pdf)TeX)|Package) .*Warning.*:(.*)");
+if (rxLatexError.indexIn(text)!=-1) 
 	{
 	setFormat(0, text.length(),ColorError);
 	}
-else if (text.indexOf("LaTeX Warning",0)!=-1) 
+else if ((rxBadBox.indexIn(text)!=-1) || (rxWarning.indexIn(text)!=-1)) 
 	{
 	setFormat(0, text.length(),ColorWarning);
 	}
